<?php


 class JSONUserFeed extends UserFeed {
 	
 	protected $json					= array();
 	
	/**
	 * Find users based on the parameters passed in
	 * 
	 * @param hash $post	The data posted from the remote server - in a real-world situation this would likely be the query to perform.
	 * 						Must contain keys user and password to validate that the remote server is allowed to use this service
	 * 						Service should be called via https so that these values are encrypted.
	 * @throws Exception
	 * @return null
	 */
 	 public function findUsers() {
 	 	
 		try {
 			// validate the method - we only accept POST
 			$this->verifyMethod();
 			
 			// validate user credentials
 			$this->verifyUser();
 			
 			// see how many we're asked for
 			if($this->noUsers == 0) {
 				throw new Exception ('There are no new users to import.', 401);
 			} 		
 		
 			// load the records
 			$this->loadUsers();
 			
 		// if any of the three steps above fail they will throw an exception which we catch, and handle here
 		} catch(Exception $e) {
 			$this->errorJSON($e->getCode(), $e->getMessage());
 			return;
 		}
 		
 		// build the JSON response
 		$this->generateJSON();
 		return;
 	} 
 	
 	/**
 	 * Return the current JSON
 	 * 
 	 * @return string $xml	The current XML for the class
 	 */
 	 public function getResponse() {
 	 	header('Content-type: application/json');
 		print(json_encode($this->json));
 	 }
 	
 	/**
 	 * Parse the records which were found into the expected format in an array
 	 * which will be JSON encoded when required
 	 */
 	 private function generateJSON() {
 		// begin building the XML
 		$this->errorJSON(0, '');
 		$this->json['NoRecords'] 	= (int)$this->fmResult->getFetchCount();
 		$this->json['Users']		= array();
 		
 		// load the fields and the records included in the result set
 		$fields						= $this->fmResult->getFields();
 		$recs						= $this->fmResult->getRecords();
 		
 		// loop through each record and field, adding the data to the XML
 		foreach($recs as $rec) {
 			$user					= array();
 			foreach($fields as $f) {
 				$user[$f]			= $rec->getField($f);
 			}
 			$this->json['Users'][]	= $user;
 		}
 		
 		$this->json['fieldMap']	= array(array('NoFields' => 2, 'map'=> array(
 			array('fm' => 'nameFirst', 'feed' => 'FirstName'),
 				array('fm' => 'nameLast', 'feed' => 'LastName')
 				))
 		);
 		
 	}
 	
 	/**
 	 * Standard code used to add the error code and message to the XML, called from multiple places, hence a function of its own
 	 * 
 	 * @param string $code
 	 * @param string $message
 	 */
 	 private function errorJSON($code, $message) {
 		$this->json['ErrorCode'] 	= $code;
 		$this->json['ErrorMessage']	= $message;
 	 }
 }