<?php


class UserFeed {
	
	// data needed for configuration and access
	protected $fm;
	protected $fmServer				= '127.0.0.1';
	protected $fmDatabase			= 'XMLSource';
	protected $fmUsername			= 'php.access';
	protected $fmPassword			= 'demo';
	protected $fmLayout				= 'Users';
	
	protected $remoteUsername		= 'xml.user';
	protected $remotePassword		= 'demo';
	
	protected $noUsers;
	protected $fmResult;
	protected $post;
	
	/**
	 * Standard class constructor
	 *
	 * Initiates connections to FM, randomly generates the number of users to return for demo purposes
	 * and instantiates the return XML
	 */
	public function __construct($post) {
		$this->fm					= new FileMaker($this->fmDatabase, $this->fmServer, $this->fmUsername, $this->fmPassword);
		$this->noUsers				= rand(0, 4);
		$this->post					= $post;
	}
	
	/**
	 * Verify the user's credentials
	 *
	 * In this example we're just checking against static values in this PHP class. In the real world you would be much more likely to perform
	 * a query against the database to ensure that the user was valid OR to use the supplied username/password as the credentials for the
	 * call to FM, thereyby allowing the FM user management to perform the authentication (though remember that user must have the PHP extended
	 * privilege if you do that.
	 *
	 * @param unknown_type $post
	 * @throws Exception
	 */
	protected function verifyUser() {
		if(!array_key_exists('user', $this->post) || $this->post['user'] != $this->remoteUsername || !array_key_exists('password', $this->post) || $this->post['password'] != $this->remotePassword) {
			throw new Exception('Invalid or missing credentials.', -1);
		}
	}
	
	/**
	 * Verify the method which was used - we only accept POST
	 */
	protected function verifyMethod() {
		if($_SERVER['REQUEST_METHOD'] != 'POST') {
			throw new Exception('Invalid method. This service only accepts POST.', -1);
		}
	}
		
	/**
	 * Loads users from the database.
	 *
	 * For demo purposes we're generating a random 2 digit number and search for that as a string in the Phone field to generate some data.
	 * In the real workd you'd perform the query necessary based on the parameters passed in the post data
	 *
	 * @throws Exception
	 */
	protected function loadUsers() {
		// create a query to FM - in this example we search for a random number in the phone number field
		$cmd						= $this->fm->newFindCommand($this->fmLayout);
		$rnd						= rand(10, 99);
		$cmd->addFindCriterion('Phone', "*{$rnd}*");
		$cmd->setRange(0, $this->noUsers);
		$this->fmResult				= $cmd->execute();
	
		// check and see if an error occured
		if(FileMaker::isError($this->fmResult)) {
			throw new Exception($this->fmResult->message, $this->fmResult->code);
		}
	}
	
	
}