<?php


 class XMLUserFeed extends UserFeed {
 	
 	protected $xml;
 	
 	public function __construct($post) {
 		$this->xml					= new SimpleXMLElement('<RemoteSite xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="http://remote.msdev.co.uk/user.xsd" />');
 		parent::__construct($post);
 	}
 	
	/**
	 * Find users based on the parameters passed in
	 * 
	 * @param hash $post	The data posted from the remote server - in a real-world situation this would likely be the query to perform.
	 * 						Must contain keys user and password to validate that the remote server is allowed to use this service
	 * 						Service should be called via https so that these values are encrypted.
	 * @throws Exception
	 * @return null
	 */
 	 public function findUsers() {
 	 	
 		try {
 			// validate the method - we only accept POST
 			$this->verifyMethod();
 			
 			// validate user credentials
 			$this->verifyUser();
 			
 			// see how many we're asked for
 			if($this->noUsers == 0) {
 				throw new Exception ('There are no new users to import.', 401);
 			} 		
 		
 			// load the records
 			$this->loadUsers();
 			
 		// if any of the three steps above fail they will throw an exception which we catch, and handle here
 		} catch(Exception $e) {
 			$this->errorXML($e->getCode(), $e->getMessage());
 			return;
 		}
 		
 		// build the XML
 		$this->generateRecordXML();
 		return;
 	} 
 	
 	/**
 	 * Return the current XML
 	 * 
 	 * @return string $xml	The current XML for the class
 	 */
 	 public function getResponse() {
 	 	header('Content-type: text/xml');
 		print($this->xml->asXML());
 	 }
 	
 	/**
 	 * Parse the records which were found into XML
 	 */
 	 private function generateRecordXML() {
 		// begin building the XML
 		$this->errorXML(0, '');
 		$this->xml->addChild('NoRecords', $this->fmResult->getFetchCount());
 		$users						= $this->xml->addChild('Users');
 		
 		// load the fields and the records included in the result set
 		$fields						= $this->fmResult->getFields();
 		$recs						= $this->fmResult->getRecords();
 		
 		// loop through each record and field, adding the data to the XML
 		foreach($recs as $rec) {
 			$user					= $users->addChild('User');
 			foreach($fields as $f) {
 				$user->addChild($f, $rec->getField($f));
 			}
 		}
 	}
 	
 	/**
 	 * Standard code used to add the error code and message to the XML, called from multiple places, hence a function of its own
 	 * 
 	 * @param string $code
 	 * @param string $message
 	 */
 	 private function errorXML($code, $message) {
 		$this->xml->addChild('ErrorCode', $code);
 		$this->xml->addChild('ErrorMessage', $message);
 	 }
 }